function [ave_fft, stdev] = average_and_stdev(data, startTime, endTime)
% [ave_fft] = average_and_stdev(data, startTime, endTime): find the average
% fft and the standard deviation of the ffts in the given segment
%==========================================================================
% Takes in:
%   data: a data structure, created by analyze_wav or
%       analyze_wav_for_violin
%   startTime: time in seconds that the averaging should start  
%   endTime: time in seconds that the averaging should stop.


%Grabs from the data structure
bins = data.fftBins_hz;
sliceTimes = data.fftSliceTimes_seconds;
fs = data.samplingFreq_Hz;


%References the find_nearest.m file in vector_aids.  This
%finds the nearest index to the the specified start and end 
%times.
startIndex=find_nearest(sliceTimes, startTime);
endIndex = find_nearest(sliceTimes, endTime);

totalIndex = startIndex:endIndex;
currentNumFfts = length(totalIndex)
interval = data.samplingFreq_Hz;

%Gets the fft slices, that correspond to the start and end times
[nrows, ncolumns] = size(data.fftSlices);
fft_matrix = data.fftSlices(1:nrows, startIndex:endIndex);

%sum is built in, and creates a row vector with the sum of each 
%column.  The sum vector is then divided by the number of columns to
%find the average.
sum_fft=sum(abs(fft_matrix'));
ave_fft = abs(sum_fft./currentNumFfts);

var = var(abs(fft_matrix'));

violin_range = [190 2500];
ind = find(bins >= violin_range(1) & bins <= ...
            violin_range(2));
v_cts = ave_fft(ind);
v_freq = bins(ind);


%plots the average fft, with the y-axis in notes instead of Hz.
ready_subplot(get_next_fig,2,1);
subplot(2,1,1);
ready_plot(0,2);
plot(log2(v_freq), v_cts,'rd-');
a = gca;
labels = {'g','g+','a','a+','b','c', 'c+', 'd', 'd+', 'e', 'f', ...
        'f+', 'g','g+','a', 'a+', 'b', 'c', 'c+', 'd', 'd+', 'e', 'f', 'f+', ...
        'g','g+','a','a+','b','c', 'c+', 'd', 'd+', 'e', 'f', 'f+',...
        'g','g+','a','a+','b','c', 'c+', 'd', 'd+', 'e'};
%        'f', 'f+','g','g+','a','a+','b','c', 'c+', 'd', 'd+' };
binFreqs =[196,207.65,220,233.08,246.94, 261.63, 277.18, 293.66, 311.13, 329.63, 349.23, ...
        369.99, 392, 415.30, 440, 466.16, 493.88, 523.25, 554.37, 587.33, 622.25, 659.26, 698.46, 739.99,...
        783.99, 830.61, 880, 932.33, 987.77, 1046.5, 1108.73, 1174.66, 1244.51, 1318.51, 1396.91, 1479.98, ...
        1567.98, 1661.22, 1760, 1864.66, 1975.53, 2093, 2217.46, 2349.32, 2489.02, 2637.02];
 %       2793.83, 2959.96, 3135.96, 3322.44, 3520, 3729.31, 3951.07, 4186.01, 4434.99, 4698.64, 4978.03];
set(a,'XTick',log2(binFreqs));
set(a,'XTickLabel',labels);


filename = data.dataFileName;
title(sprintf('%s, average from %f to %f seconds',filename, startTime, endTime)); 
xlabel(sprintf('frequency in Hz'));

%plots the standard deviation of the fft, with the x-axis in notes instead of Hz.
subplot(2,1,2);
v_cts = var(ind);
v_freq = bins(ind);
plot(log2(v_freq),abs(v_cts),'r.-');
title(sprintf('%s, variance from %f to %f seconds',filename, startTime, endTime)); 
xlabel(sprintf('frequency in Hz, converted to note name'));
a = gca;
labels = {'g','g+','a','a+','b','c', 'c+', 'd', 'd+', 'e', 'f', ...
        'f+', 'g','g+','a', 'a+', 'b', 'c', 'c+', 'd', 'd+', 'e', 'f', 'f+', ...
        'g','g+','a','a+','b','c', 'c+', 'd', 'd+', 'e', 'f', 'f+',...
        'g','g+','a','a+','b','c', 'c+', 'd', 'd+', 'e',...
        'f', 'f+','g','g+','a','a+','b','c', 'c+', 'd', 'd+' };

binFreqs =[196,207.65,220,233.08,246.94, 261.63, 277.18, 293.66, 311.13, 329.63, 349.23, ...
        369.99, 392, 415.30, 440, 466.16, 493.88, 523.25, 554.37, 587.33, 622.25, 659.26, 698.46, 739.99,...
        783.99, 830.61, 880, 932.33, 987.77, 1046.5, 1108.73, 1174.66, 1244.51, 1318.51, 1396.91, 1479.98, ...
        1567.98, 1661.22, 1760, 1864.66, 1975.53, 2093, 2217.46, 2349.32, 2489.02, 2637.02, ...
        2793.83, 2959.96, 3135.96, 3322.44, 3520, 3729.31, 3951.07, 4186.01, 4434.99, 4698.64, 4978.03];
set(a,'XTick',log2(binFreqs));
set(a,'XTickLabel',labels);

