function [fixed_fft, maximum] = cut_noise(fftMag, bins)
%[fixed_fft, maximum] = cut_noise(fft, bins) :gets rid of noise
%================================================================
% cut_noise takes in an fft vector and a vector of bin frequencies,
% and subtracts out the highest magnitude from under 100 Hz (where most
% of the noise comes from). 

%This returns the indicies of the bins that are less that 100 Hz.
truncated_bins= find(bins<=100);

%finds how long the vector of indicies is, then creates a vector
%of fft magnitudes that corespond to 100 Hz and less (assuming
%that the bin frequencies are always increasing, which is a pretty
%safe assumption.
nbins = length(truncated_bins);
truncated_fft = fftMag(1:nbins);

%finds the maximum magnitude for frequencies less than 100 Hz
maximum = max(abs(truncated_fft));

%subtracts the max from the entire fft vector
fft_minus_noise=abs(fftMag)-maximum;

% creates a vector of ones and zeros, where the ones mean that the 
% value of the fft is non-negative.
fixed_fft1 = (fft_minus_noise>0);

% finally, creates an fft where the noise is subtracted out.
fixed_fft = fixed_fft1.*fft_minus_noise;

%plotting
ready_plot(-1,2);
plot(bins, fixed_fft)
scale_xaxis(0, 10000, gcf);
title(sprintf('cut noise fft')); 
xlabel(sprintf('frequency in Hz'));



