function draw_an_fft_norm(res,start,n)
% draw_an_fft_norm(res, start, n) draws a normalized fft using the built-in specgram
% function
%==========================================================================
% Takes in:
%   res: a data structure, created by analyze_wav or
%       analyze_wav_for_violin
%   start: time in seconds that the fft should start  
%   n: number of samples in the fft.

%gets data from the res structure
data = res.samples;
time = res.sampleTimes_seconds;
fs = res.samplingFreq_Hz;
interval = n/fs;

%uses the built-in fucntion find to create a vector of the data that should
%go into the specgram function.
ind = find(time >= start);
fftData = data(ind(1):ind(1)+n);
[cts,freqs] = specgram(fftData,n,fs);

%Finds the frequencies in the range of the violin.
violin_range = [170 2700];
ind = find(freqs >= violin_range(1) & freqs <= ...
            violin_range(2));
        
%creates vectors of the magnitude and frequencies for the appropriate range of frequencies. 
v_cts = abs(cts(ind));
v_freq = freqs(ind);

%normalizing area under curve to one
sumTotal = sum(v_cts)/interval;
v_cts = v_cts./sumTotal;

%plotting, with the x-axis in notes instead of Hz.
ready_plot(-1, 2);
plot(log2(v_freq), v_cts,'b.-');
a = gca;
labels = {'g','g+','a','a+','b','c', 'c+', 'd', 'd+', 'e', 'f', ...
        'f+', 'g','g+','a', 'a+', 'b', 'c', 'c+', 'd', 'd+', 'e', 'f', 'f+', ...
        'g','g+','a','a+','b','c', 'c+', 'd', 'd+', 'e', 'f', 'f+',...
        'g','g+','a','a+','b','c', 'c+', 'd', 'd+', 'e'};
%        'f', 'f+','g','g+','a','a+','b','c', 'c+', 'd', 'd+' };
binFreqs =[196,207.65,220,233.08,246.94, 261.63, 277.18, 293.66, 311.13, 329.63, 349.23, ...
        369.99, 392, 415.30, 440, 466.16, 493.88, 523.25, 554.37, 587.33, 622.25, 659.26, 698.46, 739.99,...
        783.99, 830.61, 880, 932.33, 987.77, 1046.5, 1108.73, 1174.66, 1244.51, 1318.51, 1396.91, 1479.98, ...\
        1567.98, 1661.22, 1760, 1864.66, 1975.53, 2093, 2217.46, 2349.32, 2489.02, 2637.02];
 %       2793.83, 2959.96, 3135.96, 3322.44, 3520, 3729.31, 3951.07, 4186.01, 4434.99, 4698.64, 4978.03];
set(a,'XTick',log2(binFreqs));
set(a,'XTickLabel',labels);
