function results = get_some_ffts(analyze_results, startSecs, endSecs, nFfts)
%get_some_ffts(analyze_results, startSecs*, endSecs*, nFfts*): grab some ffts w/in given time period
%====================================================================================================
%analyze_results: structure returned from analzye_wav_for_violin (can be either the clipped or
%   non-clipped results returned by that function).
%startSecs: place to start picking out FFTs (0 is default)
%endSecs: place to end picking out FFTs (end of analyze_results is default)
%nFfts: how many to pick out 
%  default: 5
%  0: return ALL fft slices w/in given range (this is what you want when you're calculating averages)
%returns structure with following fields:
%   .fftSlices
%   .fftSliceTimes_seconds
%   .fftBins_hz
%

finalTime = last(analyze_results.fftSliceTimes_seconds);


if nargin < 2
  startSecs = 0;
  endSecs = finalTime;
  nFfts = 5;
end
if nFfts == 0
  takeAll = 1;
else
  takeAll = 0;
end

%make sure we don't get too many samples

samplingInterval = analyze_results.samplingInterval_seconds;

%arguement checking
ck_between(startSecs,0,finalTime);
ck_between(endSecs,0,finalTime);
assert(startSecs <= endSecs,'bogus time span requested');

n = length(analyze_results.samples);
startInd = find_nearest(startSecs,analyze_results.fftSliceTimes_seconds);
endInd = find_nearest((endSecs-samplingInterval),analyze_results.fftSliceTimes_seconds);

if takeAll
  inds = startInd:1:endInd;
else
  inds = round(enumerate_nDivs_indices(startInd,endInd,nFfts));
  if ~is_uniqInds(inds)
     disp('warning: you are asking for more divisions w/in this time period than exist');
  end
end

results = struct('fftSlices',analyze_results.fftSlices(:,inds),...
                 'fftSliceTimes_seconds',analyze_results.fftSliceTimes_seconds(inds),...
                 'fftBins_hz',analyze_results.fftBins_hz, 'indicies', inds);
