function template_bin_res(mode)
%template_bin_res(mode): analyzes average template data to find their bin resolutions
%======================================================================================
%mode 1: note_file_names
%mode 2: test_file_names
%--------------------------------------------------------------------------------------
%this fn allows us to determine when some of violin transc team's wav files were
%saved at resolutions other than than 22050 kHz

switch mode
case 1, [bins, ffts, names] = get_note_templates;
case 2, [bins, ffts, names ] = get_test_templates;
otherwise, assert(0,'bogus mode');
end

n = length(bins);
mins = zeros(1,n);
maxs = zeros(1,n);
diffs = zeros(1,n);

for i = 1:1:n
    thisData = bins{i};
    m = length(thisData);
    tmp_diffs = thisData(2:m)-thisData(1:m-1);
    %this function checks for equality of distance between bin values w/in some small range
    %   (eps is a function provided by matlab)
    ck_within(tmp_diffs,tmp_diffs(1),eps*2);
    diffs(i) = tmp_diffs(1);
    mins(i) = min(thisData);
    maxs(i) = max(thisData);
end

%display for each file its min and max bin value, as well as each file's difference between
%  adjacent bin values
nr = 3; nc = 1;
ready_subplot(get_next_fig,nr,nc);
subplot(nr,nc,1);
simple_hist(0,mins,100);
title('mins');
subplot(nr,nc,2);
simple_hist(0,maxs,100);
title('maxs');
subplot(nr,nc,3);
simple_hist(0,diffs,100);
title('diffs');

%now that i've figured out from the above figures that there are exactly two 
%and only 2 types of bin vectors, lets show which files are which 
%note: i used the above histograms (the max one) to visually determined that 17e4 is 
%  a good discriminator for identifying which is which
inds = find(maxs > 1.7e4);
if length(inds) > 1
    disp(sprintf('%d notes with the %d sized max bin',length(inds),maxs(inds(1))));
    numPerLine = 6;
    for i = 1:numPerLine:length(inds)
        s = [];
        for j = 0:1:5
            if(i + j <= length(inds))
                s = [s sprintf('%s\t',names{inds(i+j)})];
            else
                
            end
        end
        disp(s);
    end
end

inds = find(maxs < 1.7e4);
disp(sprintf('%d notes with the %d sized max bin',length(inds),maxs(inds(1))));
numPerLine = 6;
for i = 1:numPerLine:length(inds)
    s = [];
    for j = 0:1:5
        if(i + j <= length(inds))
            s = [s sprintf('%s\t',names{inds(i+j)})];
        else
            
        end
    end
    disp(s);
end
    
